@@ -1,9 +1,10 @@
 import requests
 from . import discordbot
 
-apikey = ''
-api_url = 'https://1.kelprepl.repl.co/api/v1/'
+apikey = ""
+api_url = "https://1.kelprepl.repl.co/api/v1/"
 name = ""
+admins = []
 
 def add_whitelist(discord_id: int):
     response = requests.post(api_url + f"premium_add?discord_id={discord_id}&api_key={apikey}")
